#!/bin/bash

# ==========
# $File: //guest/adam_morriss/scripts/findchange.sh $
# $Revision: #8 $
# $Change: 18558 $
#
# $Author: amo $
# $DateTimeTZ: 2016/03/08 11:05:43 -0800 PST $
# ----------
# Bash script for searching change descriptions for a given string.
#
# Takes four parameters:
# status:	one of pending, shelved, submitted
# depth: 	an integer
# pattern:	the string for which you are searching
# depotpath:	a pattern for matching files, eg. //depot/path/...
#
# With this information, the script builds a 'p4 changes' command
# then searches each change for the string given. 
# ==========

stat=$1
deep=$2
patt=$3
path=$4

# messages
usage="$0 status depth pattern depotpath"
stats="Status: pending | shelved | submitted"
nstat="Unknown status: $stat"
nonum="Non-numeric depth: $deep"
param="Unexpected parameters provided - need four."
npath="Ignoring path ($path) for status '$stat'"

if [ "$#" -eq 0 ]; then echo $usage; exit 0; fi

if ! [[ $deep =~ ^[0-9]+$ ]] ; then 
	echo $usage
	echo $nonum
	exit 2
fi

if [ "$#" -ne 4 ]; then
	echo $usage
	echo $param
	exit 1
else
	echo "Searching the last $deep changes in '$path' for descriptions containing '$patt'"
fi

total=0
found=0

chgs=`p4 -F %change% -ztag changes -s $stat -m$deep $path`

for c in $chgs; do
	testdesc=`p4 -F %Description% -ztag change -o $c | grep -e "$patt"`
	rc=$?; if [[ $rc == 0 ]]; then echo "Change: $c"; (( found++ )); fi 
	(( total++ ))
done
echo Searched $total, found $found
